/*
    nowlisteningpreferences.h

    Kopete Now Listening To plugin

    Copyright (c) 2002,2003,2004 by Will Stephenson <will@stevello.free-online.co.uk>

    Kopete    (c) 2002,2003,2004 by the Kopete developers  <kopete-devel@kde.org>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/

#ifndef NOWLISTENINGPREFERENCES_H
#define NOWLISTENINGPREFERENCES_H

#include <tdecmodule.h>

class NowListeningPrefsUI;
class NowListeningConfig;

/**
  *@author Will Stephenson
  */

class NowListeningPreferences : public TDECModule
{
TQ_OBJECT
  
public:
	NowListeningPreferences(TQWidget *parent = 0, const char *name = 0, const TQStringList &args = TQStringList());
	virtual ~NowListeningPreferences();
	virtual void save();
	virtual void load();
	virtual void defaults();

private slots:
	void slotSettingsChanged();

private:
	NowListeningPrefsUI *preferencesDialog;

};

#endif
